@@ -32,7 +32,7 @@ from pybroker.cache import (
 from pybroker.common import BarData, DataCol, Day, FeeMode, PriceType
 from pybroker.context import ExecContext
 from pybroker.config import StrategyConfig
-from pybroker.data import AKShare, Alpaca, AlpacaCrypto, YFinance
+from pybroker.data import Alpaca, AlpacaCrypto, YFinance
 from pybroker.eval import EvalMetrics, BootstrapResult
 from pybroker.indicator import (
     Indicator,
@@ -58,4 +58,4 @@ from pybroker.vect import cross, highv, lowv, sumv
 # https://github.com/numba/numba/issues/8940
 from numba.np.unsafe import ndarray
 
-__version__ = "1.1.19"
+__version__ = "1.1.24"
