@@ -19,7 +19,7 @@ with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import numpy as np
 import pandas as pd
-from .common import (
+from pybroker.common import (
     BarData,
     DataCol,
     IndicatorSymbol,
@@ -28,14 +28,16 @@ from .common import (
     TrainedModel,
     to_decimal,
 )
-from .log import Logger
+from pybroker.log import Logger
 from collections import defaultdict
 from decimal import Decimal
 from diskcache import Cache
 from numpy.typing import NDArray
 from typing import (
+    Any,
     Callable,
     Collection,
+    Final,
     Iterable,
     Literal,
     Mapping,
@@ -45,6 +47,8 @@ from typing import (
     Union,
 )
 
+_EMPTY_PARAM: Final = object()
+
 
 class StaticScope:
     """A static registry of data and object references.
@@ -91,6 +95,7 @@ class StaticScope:
         )
         self.custom_data_cols = set()
         self._cols_frozen: bool = False
+        self._params: dict[str, Any] = {}
 
     def set_indicator(self, indicator):
         """Stores :class:`pybroker.indicator.Indicator` in static scope."""
@@ -172,6 +177,15 @@ class StaticScope:
         """
         self._cols_frozen = False
 
+    def param(
+        self, name: str, value: Optional[Any] = _EMPTY_PARAM
+    ) -> Optional[Any]:
+        """Get or set a global parameter."""
+        if value == _EMPTY_PARAM:
+            return self._params.get(name, None)
+        self._params[name] = value
+        return value
+
     @classmethod
     def instance(cls) -> "StaticScope":
         """Returns singleton instance."""
@@ -210,6 +224,11 @@ def unregister_columns(names: Union[str, Iterable[str]], *args):
     StaticScope.instance().unregister_custom_cols(names, *args)
 
 
+def param(name: str, value: Optional[Any] = _EMPTY_PARAM) -> Optional[Any]:
+    """Get or set a global parameter."""
+    return StaticScope.instance().param(name, value)
+
+
 class ColumnScope:
     """Caches and retrieves column data queried from :class:`pandas.DataFrame`.
 
@@ -361,16 +380,25 @@ class IndicatorScope:
 
 
 class ModelInputScope:
-    """Caches and retrieves model input data.
+    r"""Caches and retrieves model input data.
 
     Args:
         col_scope: :class:`.ColumnScope`.
         ind_scope: :class:`.IndicatorScope`.
+        models: :class:`Mapping` of
+            :class:`pybroker.common.ModelSymbol` pairs to
+            :class:`pybroker.common.TrainedModel`\ s.
     """
 
-    def __init__(self, col_scope: ColumnScope, ind_scope: IndicatorScope):
+    def __init__(
+        self,
+        col_scope: ColumnScope,
+        ind_scope: IndicatorScope,
+        models: Mapping[ModelSymbol, TrainedModel],
+    ):
         self._col_scope = col_scope
         self._ind_scope = ind_scope
+        self._models = models
         self._sym_inputs: dict[ModelSymbol, pd.DataFrame] = {}
         self._scope = StaticScope.instance()
 
@@ -405,7 +433,20 @@ class ModelInputScope:
         for ind_name in self._scope.get_indicator_names(name):
             input_[ind_name] = self._ind_scope.fetch(symbol, ind_name)
         df = pd.DataFrame.from_dict(input_)
-        df = self._scope.get_model_source(name).prepare_input_data(df)
+        if model_sym not in self._models:
+            raise ValueError(f"Model {name!r} not found for {symbol}.")
+        trained_model = self._models[model_sym]
+        if trained_model.input_cols is not None:
+            for input_col in trained_model.input_cols:
+                if input_col not in df.columns:
+                    raise ValueError(
+                        f"Missing column {input_col!r} for input data to "
+                        f"model {model_sym.model_name!r}."
+                    )
+            df = df[list(trained_model.input_cols)]
+        model_source = self._scope.get_model_source(name)
+        if not trained_model.input_cols or model_source._input_data_fn:
+            df = model_source.prepare_input_data(df)
         self._sym_inputs[model_sym] = df
         return df if end_index is None else df.loc[: end_index - 1]
 
@@ -449,6 +490,12 @@ class PredictionScope:
         if model_sym in self._sym_preds:
             return self._sym_preds[model_sym][:end_index]
         input_ = self._input_scope.fetch(symbol, name)
+        if input_.empty:
+            raise ValueError(
+                f"No input data found for model {name!r}. Consider "
+                "passing input_data_fn to pybroker#model() if custom columns "
+                "were registered."
+            )
         if model_sym not in self._models:
             raise ValueError(f"Model {name!r} not found for {symbol}.")
         trained_model = self._models[model_sym]
