@@ -61,7 +61,7 @@ from pybroker.scope import (
     PriceScope,
     StaticScope,
 )
-from pybroker.slippage import SlippageData, SlippageModel
+from pybroker.slippage import SlippageModel
 from collections import defaultdict, deque
 from dataclasses import dataclass
 from datetime import datetime
@@ -272,6 +272,7 @@ class BacktestMixin:
                     buy_results=pos_size_buy_results,
                     sell_results=sell_sched[date] if is_sell_sched else None,
                 )
+            portfolio.check_stops(date, price_scope)
             if is_cover_sched:
                 self._place_buy_orders(
                     date=date,
@@ -299,7 +300,6 @@ class BacktestMixin:
                     portfolio=portfolio,
                     enable_fractional_shares=enable_fractional_shares,
                 )
-            portfolio.check_stops(date, price_scope)
             portfolio.capture_bar(date, test_data)
             if before_exec_fn is not None and active_ctxs:
                 before_exec_fn(active_ctxs)
@@ -371,8 +371,9 @@ class BacktestMixin:
     ):
         buy_shares = to_decimal(ctx.buy_shares) if ctx.buy_shares else None
         sell_shares = to_decimal(ctx.sell_shares) if ctx.sell_shares else None
-        data = SlippageData(buy_shares=buy_shares, sell_shares=sell_shares)
-        slippage_model.apply_slippage(data, ctx)
+        slippage_model.apply_slippage(
+            ctx, buy_shares=buy_shares, sell_shares=sell_shares
+        )
 
     def _exit_position(
         self,
@@ -1465,12 +1466,14 @@ class Strategy(
             calc_bootstrap=calc_bootstrap,
             bootstrap_sample_size=self._config.bootstrap_sample_size,
             bootstrap_samples=self._config.bootstrap_samples,
-            sharpe_length=self._config.sharpe_length,
-        )
-        metrics_df = pd.DataFrame(
-            dataclasses.asdict(eval_result.metrics).items(),
-            columns=["name", "value"],
+            bars_per_year=self._config.bars_per_year,
         )
+        metrics = [
+            (k, v)
+            for k, v in dataclasses.asdict(eval_result.metrics).items()
+            if v is not None
+        ]
+        metrics_df = pd.DataFrame(metrics, columns=["name", "value"])
         self._logger.walkforward_completed()
         return TestResult(
             start_date=start_date,
